@@ -220,7 +220,7 @@ class Connection():
     def __is__join_select__(self, field):
         if '.' in field:
             table_name = field.split('.')[0].strip()
-            return not self.__is_join__(table_name)
+            return self.__is_join__(table_name)
         else:
             return False
 
@@ -314,7 +314,6 @@ class Connection():
         _select = f"{_select}, {_alias}" if _alias else f"{_select}"
 
         _select_join, _join = self.__format_join_query__(self._join, 'LEFT')
-
         _select_join = f', {_select_join}' if _select_join != '' else ''
 
         _select_inner, _inner = self.__format_join_query__(self._inner, 'INNER')
@@ -329,7 +328,7 @@ class Connection():
         _groupby =  '' if not self._groupby else f" GROUP BY ({self._groupby})"
 
         # HAVING BLOCK
-        _having = '' if not self._having else f" HAVING ({' AND '.join(self._having)})"
+        _having = '' if not self._having else f" AND ({' AND '.join(self._having)})"
         _orhaving = '' if len(self._orhaving) == 0 else  ''.join([f" OR ({' AND '.join([w for w in conditions])})" for block, conditions in self._orhaving.items()])
 
         # ORDER BLOCK
@@ -338,7 +337,7 @@ class Connection():
         # LIMIT BLOCK
         _limit = '' if not self._limit else f" LIMIT {self._limit[0]},{self._limit[1]}"
 
-        _stetament =  f"SELECT {_select} {_select_join} {_select_inner} FROM {self._table} {_join} {_inner} {_where}{_orwhere}{_groupby}{_having}{_orhaving}{_orderby}{_limit}"
+        _stetament =  f"SELECT {_select} FROM {self._table} {_join} {_inner} {_where}{_orwhere}{_groupby}{_having}{_orhaving}{_orderby}{_limit}"
 
         return  _stetament
 
@@ -420,6 +419,14 @@ class Connection():
         self._include = self.__format_relationship__(*tables)
         return self
 
+    def execute(self, query, class_name=None):
+        result = self._conn.fetchall(query)
+        if class_name:
+            _class = getattr(__import__(f'model.{class_name.lower()}', fromlist=[class_name]), class_name)
+            _klass = _class()
+            result = ListType(_class).add([_class(**item) for item in result])
+        return result
+
     @property
     def fetch(self):
         query = self.__format_select_query__()
@@ -460,12 +467,13 @@ class Connection():
 
         return item
 
+
     @property
     def count(self):
         Debug("Formating Query")
         query = self.__format_count_query__()
         result = self._conn.fetchall(query)
-        return result[0]["COUNT(*)"]
+        return result[0]["COUNT(*)"] if len(result) > 0  else 0
 
     def __commit__(self, obj, action):
         [ v.remove(obj) for k, v in self.__queue__.items() if k != action and obj in v]
