@@ -30,11 +30,12 @@ def Make(dir, db_user, db_password, db_host, db_port, db_database, db_ssl=False,
     print("\n [ Python Entity Model ] \n")
 
     root_path = dir
-    model_path = "{}/model".format(root_path)
+    model_path = "{}/model/".format(root_path)
+    model_lib_path = "{}/model/lib/".format(root_path)
 
     # create model path
-    if not os.path.exists(model_path):
-        os.mkdir(model_path)
+    if not os.path.exists(model_lib_path):
+        os.mkdir(model_lib_path)
         print("\t\u2714 Creating Model Folder on Project")
     else:
         print("\t\u2714 Model Folder Exists")
@@ -110,8 +111,8 @@ def Make(dir, db_user, db_password, db_host, db_port, db_database, db_ssl=False,
         table_columns = [
             column for column in columns if column["TABLE_NAME"] == table["TABLE_NAME"]]
 
-        path_entitie = "{}/{}.py".format(model_path, classname.lower())
-        models.append("from model.{} import {}".format(
+        path_entitie = "{}/{}.py".format(model_lib_path, classname.lower())
+        models.append("from model.lib.{} import {}".format(
             classname.lower(), classname))
 
         print("\t\t\u2714 Creating Model: {} : {}".format(
@@ -197,13 +198,31 @@ def Make(dir, db_user, db_password, db_host, db_port, db_database, db_ssl=False,
             entitie.write("\n\n\t\tsuper().__init__(**kw)")
             entitie.write("\n")
 
+        # WRITE MODEL PY FILE
+        path_model = "{}/{}.py".format(model_path, classname.lower())
+        if not os.path.exists(path_model):
+            with open(path_model, "w") as model_entitie:
+                model_entitie.write("# -*- coding: utf-8 -*-")
+                model_entitie.write(f"\nfrom bravaorm.entity.datatype import *")
+                model_entitie.write(f"\nfrom .lib import {classname}")
+                model_entitie.write(f"\n\nclass {classname}({classname}):")
+                model_entitie.write("\n\n\tdef __init__(cls, **kw):")
+                model_entitie.write(f"\n\t\treturn super({classname}, cls).__init__(**kw)")
+
     # init model path
 
     # INICIA PASTA LIB ENTITY __INIT__.PY
-    with open("{}/__init__.py".format(model_path), "w") as lib_init_file:
+    with open("{}/__init__.py".format(model_lib_path), "w") as lib_init_file:
         lib_init_file.write("#-*- coding: utf-8 -*-\n\n")
         lib_init_file.write("\n".join(models))
 
+    print("\n\t\u2714 LIB Init py folder")
+
+    # INICIA PASTA MODEL __INIT__.PY
+    with open("{}/__init__.py".format(model_path), "w") as lib_init_file:
+        lib_init_file.write("#-*- coding: utf-8 -*-\n\n")
+        lib_init_file.write("\n".join(models).replace('model.lib.', 'model.'))
+
     print("\n\t\u2714 Init py folder")
 
     print("\n\t\u2714 Done!\n\n")
